@@ -1,8 +1,8 @@
 import sys
-import json
 import os
 import logging
 import logging.config
+import simplejson as json
 
 from singer import utils
 from singer import transform
@@ -146,7 +146,7 @@ class ActivateVersionMessage(Message):
         }
 
 def format_message(message):
-    return json.dumps(message.asdict())
+    return json.dumps(message.asdict(), use_decimal=True)
 
 def write_message(message):
     sys.stdout.write(format_message(message) + '\n')
